summaryrefslogtreecommitdiffstats
path: root/libkonq/tdefileivi.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:14:55 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:14:55 -0600
commitde9b6c9ad15f9f51812daae17cce635d1050a9ba (patch)
tree6b26400ab1a616925443c5d365246eb86c9bad57 /libkonq/tdefileivi.h
parent4f841fbbbc5d3399535ade061699cc76363c7a3f (diff)
downloadtdebase-de9b6c9ad15f9f51812daae17cce635d1050a9ba.tar.gz
tdebase-de9b6c9ad15f9f51812daae17cce635d1050a9ba.zip
Rename KIcon to enhance compatibility with KDE4
Diffstat (limited to 'libkonq/tdefileivi.h')
-rw-r--r--libkonq/tdefileivi.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/libkonq/tdefileivi.h b/libkonq/tdefileivi.h
index e9e0cf420..9d940a023 100644
--- a/libkonq/tdefileivi.h
+++ b/libkonq/tdefileivi.h
@@ -30,12 +30,12 @@ class KIVDirectoryOverlay;
/**
* KFileIVI (short form of "Konq - File - IconViewItem")
* is, as expected, an improved KIconViewItem, because
* it represents a file.
* All the information about the file is contained in the KFileItem
* pointer.
*/
-class LIBKONQ_EXPORT KFileIVI : public KIconViewItem
+class LIBKONQ_EXPORT KFileIVI : public TDEIconViewItem
{
public:
/**
@@ -67,12 +67,12 @@ public:
/**
* Changes the icon for this item.
* @param size the icon size (0 for default, otherwise size in pixels)
* @param state the state of the icon (enum in KIcon)
* @param recalc whether to update the layout of the icon view when setting the icon
* @param redraw whether to redraw the item after setting the icon
*/
virtual void setIcon( int size,
- int state=KIcon::DefaultState,
+ int state=TDEIcon::DefaultState,
bool recalc=false,
bool redraw=false);
@@ -92,7 +92,7 @@ public:
* e.g. because the effect settings have been changed. The thumb itself
* is assumed to be still valid (use setThumbnailPixmap() instead
* otherwise).
* @param state the state of the icon (enum in KIcon)
* @param redraw whether to redraw the item after setting the icon
*/
void invalidateThumb( int state, bool redraw = false );
@@ -108,7 +108,7 @@ public:
/**
* Return the current state of the icon
- * (KIcon::DefaultState, KIcon::ActiveState etc.)
+ * (TDEIcon::DefaultState, TDEIcon::ActiveState etc.)
*/
int state() const { return m_state; }
@@ -128,8 +128,8 @@ public:
void setThumbnailPixmap( const TQPixmap & pixmap );
/**
* Set the icon to use the specified KIconEffect
* See the docs for KIconEffect for details.
*/
void setEffect( /*int group,*/ int state );
@@ -214,9 +214,9 @@ protected:
private:
/** You are not supposed to call this on a KFileIVI, from the outside,
* it bypasses the icons cache */
- virtual void setPixmap ( const TQPixmap & icon ) { KIconViewItem::setPixmap( icon ); }
+ virtual void setPixmap ( const TQPixmap & icon ) { TDEIconViewItem::setPixmap( icon ); }
virtual void setPixmap ( const TQPixmap & icon, bool recalc, bool redraw = TRUE )
- { KIconViewItem::setPixmap( icon, recalc, redraw ); }
+ { TDEIconViewItem::setPixmap( icon, recalc, redraw ); }
/** Check if a thumbnail will be generated and calc the size of the icon */
void updatePixmapSize();
@@ -30,12 +30,12 @@ class KIVDirectoryOverlay;
/**
* KFileIVI (short form of "Konq - File - IconViewItem")
- * is, as expected, an improved KIconViewItem, because
+ * is, as expected, an improved TDEIconViewItem, because
* it represents a file.
* All the information about the file is contained in the KFileItem
@@ -67,12 +67,12 @@ public:
* Changes the icon for this item.
* @param size the icon size (0 for default, otherwise size in pixels)
- * @param state the state of the icon (enum in KIcon)
+ * @param state the state of the icon (enum in TDEIcon)
* @param recalc whether to update the layout of the icon view when setting the icon
* @param redraw whether to redraw the item after setting the icon
@@ -92,7 +92,7 @@ public:
* is assumed to be still valid (use setThumbnailPixmap() instead
* otherwise).
- * @param state the state of the icon (enum in KIcon)
+ * @param state the state of the icon (enum in TDEIcon)
* @param redraw whether to redraw the item after setting the icon
*/
@@ -128,8 +128,8 @@ public:
void setThumbnailPixmap( const TQPixmap & pixmap );
/**
- * Set the icon to use the specified KIconEffect
- * See the docs for KIconEffect for details.
+ * Set the icon to use the specified TDEIconEffect
+ * See the docs for TDEIconEffect for details.
*/
void setEffect( /*int group,*/ int state );